==> 0.3.2.tar.gz: example/dotup_flutter_widgets_example/lib/SectionExamplePage.dart <==
import 'package:dotup_flutter_widgets/themes/ThemeProvider.dart';
import 'package:dotup_flutter_widgets/scroll_wheel/ScrollWheel.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:provider/provider.dart';

class SectionExamplePage extends StatefulWidget {
  const SectionExamplePage({
    Key? key,
  }) : super(key: key);

  @override
  _SectionExamplePageState createState() => _SectionExamplePageState();
}

class _SectionExamplePageState extends State<SectionExamplePage> {
  bool checkValue = false;
  bool switchValue = false;
  var groupValue = '1';
  String? dropdownValue;
  late String popupValue;

  @override
  void initState() {
    popupValue = 'Popup menu button';
    super.initState();
  }

  @override
  build(BuildContext context) {
    final color = Theme.of(context).accentColor; // Colors.white70;
    final theme = Provider.of<ThemeProvider>(context, listen: false);

    return Scaffold(
      // title: 'zeiTick',
      // actions: [_buildAvatar(context)],
      // backgroundColor: Theme.of(context).buttonColor,
      // appBar: _buildAppBar(context),
      // body: _buildBody(context),
      // drawer: AppDrawer.standard(context),
      body: SectionView(
        padding: const EdgeInsets.all(0.0),
        children: [
          Section(
            header: SectionHeader(
              text: 'Header',
            ),
            children: [
              SectionTile(text: 'SectionTile', color: color),
              SectionTile.switchButton(
                text: 'Dark mode',
                onChanged: (value) {
                  theme.switchTheme(value);
                },
                switchButtonValue: theme.isDarkMode,
                color: color,
              ),
              SectionTile.button(
                text: 'Show color picker',
                onTap: () async {
                  final newColor = await showColorPickerPage(context, null, '');
                  theme.changePrimaryColor(newColor);
                  theme.changeAccentColor(newColor);
                },
                color: Colors.red,
                icon: Icon(
                  Icons.delete,
                  color: Colors.red,
                ),
              ),
              SectionTile.scrollWheelInfinite(
                width: 50,
                text: 'ScrollWheel',
                color: color,
                items: List.generate(10, (index) => '$index-oha'),
                onChange: (value) => print(value),
              ),
              SectionTile.dropdownButton<String>(
                text: 'Dropdown button',
                color: color,
                items: List.generate(4, (index) => 'Item $index'),
                onChanged: (value) {
                  setState(() {
                    dropdownValue = value;
                  });
                },
                value: dropdownValue,
              ),
              SectionTile.popupMenuButton<String>(
                text: popupValue,
                color: color,
                items: List.generate(4, (index) => 'Item $index')..add('Popup menu button'),
                // icon: Icon(Icons.arrow_drop_down),
                onSelected: (value) {
                  setState(() {
                    popupValue = value;
                  });
                },
                initialValue: popupValue,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: Center(
                  child: ScrollWheel(
                    width: 50,
                    items: List.generate(10, (index) => '$index-oha'),
                    onChange: (value) => print(value),
                  ),
                ),
              ),
              SectionTile.switchButton(
                  text: 'switchButton',
                  onChanged: switchChanged,
                  color: color,
                  activeColor: color,
                  switchButtonValue: switchValue),
              SectionTile.switchButton(
                  text: 'switchButton', onChanged: switchChanged, color: color, switchButtonValue: switchValue),
              SectionTile.scrollWheelTimeSelector(
                text: 'switchButton',
                onChanged: (value) => print(value),
                color: color,
              ),
              SectionTile.checkbox(text: 'checkbox', onChanged: checkboxChanged, color: color, value: checkValue),
              SectionTile.checkbox(text: 'checkbox', onChanged: checkboxChanged, color: color, value: checkValue),
              SectionTile.button(text: 'button', onTap: () {}, color: color),
              SectionTile.button(text: 'delete all', onTap: () {}, color: Colors.red),
              SectionTile.button(
                text: 'Icon button',
                onTap: () {},
                color: Colors.red,
                icon: Icon(
                  Icons.delete,
                  color: Colors.red,
                ),
              ),
              SectionTile.navigator(
                text: 'Navigate to Color Palette',
                color: color,
                onTap: () async {
                  // final color = await Navigator.of(context).push(MaterialPageRoute(
                  //   builder: (context) => ColorSelectorPage(),
                  // ));
                  final color = await showColorSelectorPage(context);
                  print(color);
                },
              ),
              SectionTile(
                text: 'text',
                color: color,
                icon: Icon(
                  Icons.delete,
                  color: Colors.red,
                ),
              ),
              SectionTile(text: 'text', color: color),
            ],
            footer: SectionFooter(
                text:
                    'Ein kleiner Hinweis zu dieser Sektion.. sdgkjhslfd kjghalkdjsfhajsddhflkjadhs asd fadsfg asdf  '),
            // color: Colors.green,
          ),
          SectionGroup(
              header: SectionHeader(
                text: 'Gruppe A',
              ),
              groupValue: groupValue,
              onChanged: (value) {
                setState(() {
                  groupValue = value.toString();
                });
                print(value);
              },
              children: [
                SectionGroupWidget(value: '1', child: Text('1')),
                SectionGroupWidget(value: '2', child: Text('2')),
                SectionGroupWidget(value: '3', child: Text('3')),
              ])
        ],
      ),
    );
  }

  Widget _getListTile({
    required String text,
    Widget? icon,
    VoidCallback? onTap,
    required Color color,
    Widget? subTitle,
  }) {
    return ListTile(
      leading: icon,
      title: Text(
        text,
        style: TextStyle(color: color),
      ),
      subtitle: subTitle,
      trailing: Icon(
        Icons.keyboard_arrow_right,
        color: color,
      ),
      onTap: onTap,
    );
  }

  void checkboxChanged(bool? value) {
    setState(() {
      checkValue = value!;
    });
  }

  void switchChanged(bool value) {
    setState(() {
      switchValue = value;
    });
  }
}

==> 0.3.4.tar.gz: example/dotup_flutter_widgets_example/lib/SectionExamplePage.dart <==
import 'package:dotup_flutter_widgets/themes/ThemeProvider.dart';
import 'package:dotup_flutter_widgets/scroll_wheel/ScrollWheel.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import 'package:dotup_flutter_widgets/dotup_flutter_widgets.dart';
import 'package:provider/provider.dart';

class SectionExamplePage extends StatefulWidget {
  const SectionExamplePage({
    Key? key,
  }) : super(key: key);

  @override
  _SectionExamplePageState createState() => _SectionExamplePageState();
}

class _SectionExamplePageState extends State<SectionExamplePage> {
  bool checkValue = false;
  bool switchValue = false;
  var groupValue = '1';
  String? dropdownValue;
  late String popupValue;

  @override
  void initState() {
    popupValue = 'Popup menu button';
    super.initState();
  }

  @override
  build(BuildContext context) {
    final color = Theme.of(context).accentColor; // Colors.white70;
    final theme = Provider.of<ThemeProvider>(context, listen: false);

    return Scaffold(
      // title: 'zeiTick',
      // actions: [_buildAvatar(context)],
      // backgroundColor: Theme.of(context).buttonColor,
      // appBar: _buildAppBar(context),
      // body: _buildBody(context),
      // drawer: AppDrawer.standard(context),
      body: SectionView(
        padding: const EdgeInsets.all(0.0),
        children: [
          Section(
            header: SectionHeader(
              text: 'Header',
            ),
            children: [
              SectionTile(text: 'SectionTile', color: color),
              SectionTile.switchButton(
                text: 'Dark mode',
                onChanged: (value) {
                  theme.switchTheme(value);
                },
                switchButtonValue: theme.isDarkMode,
                color: color,
              ),
              SectionTile.button(
                text: 'Show color picker',
                onTap: () async {
                  final newColor = await showColorPickerPage(context, null, '');
                  theme.changePrimaryColor(newColor);
                  theme.changeAccentColor(newColor);
                },
                color: Colors.red,
                icon: Icon(
                  Icons.delete,
                  color: Colors.red,
                ),
              ),
              SectionTile.scrollWheelInfinite(
                width: 50,
                text: 'ScrollWheel',
                color: color,
                items: List.generate(10, (index) => '$index-oha'),
                onChange: (value) => print(value),
              ),
              SectionTile.dropdownButton<String>(
                text: 'Dropdown button',
                color: color,
                items: List.generate(4, (index) => 'Item $index'),
                onChanged: (value) {
                  setState(() {
                    dropdownValue = value;
                  });
                },
                value: dropdownValue,
              ),
              SectionTile.popupMenuButton<String>(
                text: popupValue,
                color: color,
                items: List.generate(4, (index) => 'Item $index')..add('Popup menu button'),
                // icon: Icon(Icons.arrow_drop_down),
                onSelected: (value) {
                  setState(() {
                    popupValue = value;
                  });
                },
                initialValue: popupValue,
              ),
              Padding(
                padding: const EdgeInsets.all(8.0),
                child: Center(
                  child: ScrollWheel(
                    width: 50,
                    items: List.generate(10, (index) => '$index-oha'),
                    onChange: (value) => print(value),
                  ),
                ),
              ),
              SectionTile.switchButton(
                  text: 'switchButton',
                  onChanged: switchChanged,
                  color: color,
                  activeColor: color,
                  switchButtonValue: switchValue),
              SectionTile.switchButton(
                  text: 'switchButton', onChanged: switchChanged, color: color, switchButtonValue: switchValue),
              SectionTile.scrollWheelTimeSelector(
                text: 'switchButton',
                onChanged: (value) => print(value),
                color: color,
              ),
              SectionTile.checkbox(text: 'checkbox', onChanged: checkboxChanged, color: color, value: checkValue),
              SectionTile.checkbox(text: 'checkbox', onChanged: checkboxChanged, color: color, value: checkValue),
              SectionTile.button(text: 'button', onTap: () {}, color: color),
              SectionTile.button(text: 'delete all', onTap: () {}, color: Colors.red),
              SectionTile.button(
                text: 'Icon button',
                onTap: () {},
                color: Colors.red,
                icon: Icon(
                  Icons.delete,
                  color: Colors.red,
                ),
              ),
              SectionTile.navigator(
                text: 'Navigate to Color Palette',
                color: color,
                onTap: () async {
                  // final color = await Navigator.of(context).push(MaterialPageRoute(
                  //   builder: (context) => ColorSelectorPage(),
                  // ));
                  final color = await showColorSelectorPage(context);
                  print(color);
                },
              ),
              SectionTile(
                text: 'text',
                color: color,
                icon: Icon(
                  Icons.delete,
                  color: Colors.red,
                ),
              ),
              SectionTile(
                icon: Icon(Icons.place),
                text: 'Arbeit',
                dense: true,
                color: color,
                subTitle: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text('Industriering 7'),
                    Text('63868 Großwallstadt'),
                  ],
                ),
              ),
            ],
            footer: SectionFooter(
                text:
                    'Ein kleiner Hinweis zu dieser Sektion.. Dies ist ein langer Footer über mehrere Zeilen.'),
            // color: Colors.green,
          ),
          SectionGroup(
              header: SectionHeader(
                text: 'Gruppe A',
              ),
              groupValue: groupValue,
              onChanged: (value) {
                setState(() {
                  groupValue = value.toString();
                });
                print(value);
              },
              children: [
                SectionGroupWidget(value: '1', child: Text('1')),
                SectionGroupWidget(value: '2', child: Text('2')),
                SectionGroupWidget(value: '3', child: Text('3')),
              ])
        ],
      ),
    );
  }

  Widget _getListTile({
    required String text,
    Widget? icon,
    VoidCallback? onTap,
    required Color color,
    Widget? subTitle,
  }) {
    return ListTile(
      leading: icon,
      title: Text(
        text,
        style: TextStyle(color: color),
      ),
      subtitle: subTitle,
      trailing: Icon(
        Icons.keyboard_arrow_right,
        color: color,
      ),
      onTap: onTap,
    );
  }

  void checkboxChanged(bool? value) {
    setState(() {
      checkValue = value!;
    });
  }

  void switchChanged(bool value) {
    setState(() {
      switchValue = value;
    });
  }
}
